@@ -24,8 +24,8 @@
  * ԥѥѹ
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/10 05:21:07 $
+ * $Revision: 1.7 $
+ * $Date: 2012/09/19 00:02:31 $
  **********************************************************/
 
 include_once("lib/dglibcommon");
@@ -36,45 +36,8 @@ include_once("lib/dglibsess");
 ƥڡ
 *********************************************************/
 
-define("OPERATION", "ԥȴ");
-
-/***********************************************************
- * 饹: ˥塼
- **********************************************************/
-Class my_page extends page {
-
-    /***********************************************************
-     * ܥǥɽʥС饤ɡ
-     **********************************************************/
-    function display_body() {
-
-        global $sesskey;
-
-print <<<EOD
-<form method="post" action="index.php">
-<table class="table">
-  <tr>
-    <td class="key1">ѥ</td>
-    <td class="value">
-      <input type="password" maxlength="8" name="newpasswd">
-    </td>
-  </tr>
-  <tr>
-    <td class="key1">ѥɡʳǧ</td>
-    <td class="value">
-      <input type="password" maxlength="8" name="re_newpasswd">
-    </td>
-  </tr>
-</table>
-<br>
-<input type="submit" name="update" value="" class="mod_btn">
-<input type="hidden" name="sk" value="$sesskey">
-</form>
-
-EOD;
-    }
-
-};
+define("OPERATION", "Controlling administrator account");
+define("TMPLFILE", "admin_adminpass_mod.tmpl");
 
 /*********************************************************
  * mod_passwd
@@ -90,7 +53,9 @@ EOD;
  **********************************************************/
 function mod_passwd ($data)
 {
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
     global $web_conf;
     global $domain;
     global $basedir;
@@ -102,7 +67,8 @@ function mod_passwd ($data)
 
     /* ѥɤΰץå */
     if ($data["newpasswd"] != $data["re_newpasswd"]) {
-        $err_msg = "ѥɤפޤ";
+        $err_msg = $msgarr['07001'][SCREEN_MSG];
+        $log_msg = $msgarr['07001'][LOG_MSG];
         return FALSE;
     }
 
@@ -111,7 +77,8 @@ function mod_passwd ($data)
     /* ѹΥѥɤȰפʤå */
     $new_passwd = md5($data["newpasswd"]);
     if ($new_passwd == $old_passwd) {
-        $err_msg = "ѥɤѹȰפޤ";
+        $err_msg = $msgarr['07002'][SCREEN_MSG];
+        $log_msg = $msgarr['07002'][LOG_MSG];
         return FALSE;
     }
 
@@ -126,21 +93,27 @@ function mod_passwd ($data)
         return FALSE;
     }
    
-    $err_msg = "ԥѥɤ򹹿ޤ";
+    $err_msg = $msgarr['07003'][SCREEN_MSG];
+    $log_msg = $msgarr['07003'][LOG_MSG];
     return TRUE; 
 }
 
 /***********************************************************
  * 
  **********************************************************/
-/* 󥹥󥹺 */
-$pg = new my_page();
+
+/*  */
+$tag["<<TITLE>>"]      = "";
+$tag["<<JAVASCRIPT>>"] = "";
+$tag["<<SK>>"]         = "";
+$tag["<<TOPIC>>"]      = "";
+$tag["<<MESSAGE>>"]    = "";
+$tag["<<TAB>>"]        = "";
 
 /* ե롢ִեɹåå */
 $ret = init();
 if ($ret === FALSE) {
-    $sys_err = TRUE;
-    $pg->display(NULL);
+    syserr_display();
     exit (1);
 }
 
@@ -151,10 +124,10 @@ if ($ret === FALSE) {
 /* ѥѹ */
 if (isset($_POST["update"])) {
     if (mod_passwd($_POST) === FALSE) {
-        result_log(OPERATION . ":NG:" . $err_msg);
+        result_log(OPERATION . ":NG:" . $log_msg);
         $err_msg = htmlspecialchars($err_msg);
     } else {
-        result_log(OPERATION . ":OK:" . $err_msg);
+        result_log(OPERATION . ":OK:" . $log_msg);
 
         /* Ѥ˥å󥭡 */
         sess_key_make($web_conf["global"]["adminname"], $_POST["newpasswd"], $sesskey);
@@ -169,7 +142,15 @@ if (isset($_POST["update"])) {
  * ɽ
  **********************************************************/
 
+/*   */
+set_tag_common($tag);
+
 /* ڡν */
-$pg->display(CONTENT);
+$ret = display(TMPLFILE, $tag, array(), "", "");
+if ($ret === FALSE) {
+    result_log($log_msg, LOG_ERR);
+    syserr_display();
+    exit(1);
+}
 
 ?>
