@@ -24,8 +24,8 @@
  * ԥѥѹ
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/10 05:21:07 $
+ * $Revision: 1.3 $
+ * $Date: 2011/09/20 06:31:54 $
  **********************************************************/
 
 include_once("lib/dglibcommon");
@@ -37,7 +37,7 @@ include_once("lib/dglibldap");
 ƥڡ
 *********************************************************/
 
-define("OPERATION", "ԥѹ");
+define("OPERATION", "Modifying administrator account");
 
 /***********************************************************
  * 饹: ˥塼
