@@ -24,10 +24,9 @@
  * ᡼󥰥ꥹԽ
  *
  * $RCSfile: mod.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/10 05:23:52 $
+ * $Revision: 1.14 $
+ * $Date: 2012/09/26 05:32:38 $
  **********************************************************/
-
 include_once("../../initial");
 include_once("lib/dglibpostldapadmin");
 include_once("lib/dglibcommon");
@@ -38,78 +37,8 @@ include_once("lib/dglibsess");
 /***********************************************************
 ƥڡ
 *********************************************************/
-
-define("OPERATION", "᡼󥰥ꥹԽ");
-
-/***********************************************************
- * 饹: ˥塼
- **********************************************************/
-Class my_page extends page {
-
-    /***********************************************************
-     * ܥǥɽʥС饤ɡ
-     **********************************************************/
-    function display_body() {
-
-        global $result;
-        global $sesskey;
-        global $dispml;
-        global $enc_ml;
-
-        $newaddr = "";
-        if (isset($_POST["newaddr"])) {
-            $newaddr = htmlspecialchars($_POST["newaddr"]);
-        }
-
-        $dispml = htmlspecialchars($dispml);
-        print <<<EOD
-
-</script>
-<form enctype="multipart/form-data" method="post" action="mod.php">
-<table class="table">
-  <tr>
-    <td class="key1">᡼󥰥ꥹȥɥ쥹</td>
-    <td class="value">$dispml</td>
-    <input type="hidden" name="mladdr" value="$enc_ml">
-  </tr>
-  <tr>
-</table>
-<table>
-    <td>
-        <select size="10" name="addr[]" multiple>
-
-EOD;
-
-        if (isset($result[0]["mailForwardingAddr"])) {
-            sort($result[0]["mailForwardingAddr"]);
-            reset($result[0]["mailForwardingAddr"]);
-            $num = 0;
-            foreach($result[0]["mailForwardingAddr"] as $i) {
-                $addr = $i;
-                $addr = htmlspecialchars($addr);
-                print("          <option value=\"$addr\">$addr" . "\n");
-            }
-        }
-
-        print <<<EOD
-        </select>
-    </td>
-    <td valign="bottom">
-        <input type="submit" name="mydel" value="" class="mail_del_btn" onClick="return msgConfirm('򤷤᡼륢ɥ쥹ޤ\\nǤ')">
-    </td>
-  </tr>
-</table>
-<br>
-<input type="text" size="40" maxlength="256" name="newaddr" value="$newaddr">
-<input type="submit" name="myadd" value="" class="add_btn">
-<br><br>
-<input type="file" size="40" name="filename">
-<input type="submit" name="myaddlist" value="" class="file_add_btn">
-<input type="hidden" name="sk" value="$sesskey">
-</form>
-EOD;
-    }
-};
+define("OPERATION", "Modifying mailinglist");
+define("TMPLFILE", "admin_ml_mod_mod.tmpl");
 
 /*********************************************************
  * mk_addr_list
@@ -127,7 +56,10 @@ EOD;
  **********************************************************/
 function mk_addr_list($nowlist, $input, &$list, $bool)
 {
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
+    global $logstr;
 
     $list = array();
 
@@ -141,14 +73,27 @@ function mk_addr_list($nowlist, $input, &$list, $bool)
         return count($list);
     }
 
+    $j = 0;
+    $err = 0;
     foreach($input as $addr) {
+        $j++;
         reset($nowlist);
         if ((array_search($addr, $nowlist) !== FALSE) === $bool) {
             $list[] = $addr;
             $i++;
+        } else {
+            $err++;
+            $err_msg .= $msgarr['12006'][SCREEN_MSG] . "(" . $j . ")<BR>";
+            $log_msg .= $msgarr['12006'][LOG_MSG]    . "(line" . $j . ")<BR>";
         }
     }
 
+    /*  顼 */
+    if ($err != 0) {
+        $logstr = OPERATION . ":NG:" . $log_msg;
+        return -1;
+    }
+
     return $i;
 }
 
@@ -156,14 +101,22 @@ function mk_addr_list($nowlist, $input, &$list, $bool)
  * 
  **********************************************************/
 
-/* 󥹥󥹺 */
-$pg = new my_page();
+/*  */
+$tag["<<TITLE>>"] = "";
+$tag["<<JAVASCRIPT>>"] = "";
+$tag["<<SK>>"] = "";
+$tag["<<TOPIC>>"] = "";
+$tag["<<MESSAGE>>"] = "";
+$tag["<<TAB>>"] = "";
+$tag["<<MLADDR>>"] = "";
+$tag["<<HIDDEN>>"] = "";
+$tag["<<NEWADDR>>"] = "";
+$tag["<<MAILADDRS>>"] = "";
 
 /* ե롢ִեɹåå */
 $ret = init();
 if ($ret === FALSE) {
-    $sys_err = TRUE;
-    $pg->display(NULL);
+    syserr_display();
     exit (1);
 }
 
@@ -171,23 +124,11 @@ if ($ret === FALSE) {
  * main
  **********************************************************/
 
-/* ᡼󥰥ꥹȤ򤵤Ƥʤ */
-if (isset($_POST["mladdr"]) === FALSE) {
-
-    $err_msg = "᡼󥰥ꥹȥɥ쥹ꤵƤޤ";
-
-    result_log(OPERATION . ":NG:" . $err_msg);
-    
-    /* ᡼󥰥ꥹȴ̤ */
-    dgp_location("index.php", $err_msg);
-    exit;
-}
-
 $mladdr = $_POST["mladdr"];
 
 /* LDAPθDN */
 if (isset($_POST["myadd"]) || isset($_POST["myaddlist"]) || isset($_POST["mydel"]) ) {
-    /* ̤Ǥʳʣ粽 */
+    /* ᡼󥰥ꥹȴ̤ܰʳʣ粽 */
     $mladdr = str_rot13($mladdr);
     $mladdr = base64_decode($mladdr);
 }
@@ -208,8 +149,9 @@ if (isset($_POST["myadd"])) {
 
     /* ɥ쥹ν񼰥å */
     if (check_mail($_POST["newaddr"]) === FALSE) {
-        $err_msg = "᡼륢ɥ쥹ηޤ";
-        $logstr = OPERATION . ":NG:" . $err_msg;
+        $err_msg = $msgarr['12002'][SCREEN_MSG];
+        $log_msg = $msgarr['12002'][LOG_MSG];
+        $logstr = OPERATION . ":NG:" . $log_msg;
     } else {
         /* ᡼륢ɥ쥹μ */
         $result = array();
@@ -218,32 +160,36 @@ if (isset($_POST["myadd"])) {
         /* LDAP˼ */
         if ($ret != LDAP_OK) {
             $sys_err = TRUE;
-            $pg->display(NULL);
-            result_log(OPERATION . ":NG:" . $err_msg);
+            result_log(OPERATION . ":NG:" . $log_msg);
+            syserr_display();
             exit (1);
         }
         $dn = $result[0]["dn"];
 
         /*᡼󥰥ꥹȥɥ쥹Ȥνʣå */
         if ($_POST["newaddr"] == $mladdr) {
-            $err_msg = "᡼륢ɥ쥹᡼󥰥ꥹ" .
-                       "ɥ쥹ȽʣƤޤ";
-            $logstr = OPERATION . ":NG:" . $err_msg;
+            $err_msg = $msgarr['12003'][SCREEN_MSG];
+            $log_msg = $msgarr['12003'][LOG_MSG];
+            $logstr = OPERATION . ":NG:" . $log_msg;
         } else {
             $attr = array("mailForwardingAddr" => $_POST["newaddr"]);
 
             /* °ɲ */
             $ret = LDAP_add_attribute($dn, $attr);
             if ($ret == LDAP_ERR_DUPLICATE) {
-                    $err_msg = "¸ߤƤ" .
-                               "᡼륢ɥ쥹ꤵƤޤ(" .
-                               $_POST["newaddr"] . ")";
-                    $logstr = OPERATION . ":NG:" . $err_msg;
+                    $err_msg = sprintf($msgarr['12004'][SCREEN_MSG],
+                                       $_POST["newaddr"]);
+                    $log_msg = sprintf($msgarr['12004'][LOG_MSG],
+                                       $_POST["newaddr"]);
+                    $logstr = OPERATION . ":NG:" . $log_msg;
             } elseif ($ret != LDAP_OK) {
-                $logstr = OPERATION . ":NG:" . $err_msg;
+                $logstr = OPERATION . ":NG:" . $log_msg;
             } else {
-                $err_msg = "᡼륢ɥ쥹ɲäޤ({$_POST["newaddr"]})";
-                $logstr = OPERATION . ":OK:" . $err_msg;
+                $err_msg = sprintf($msgarr['12005'][SCREEN_MSG],
+                                   $_POST["newaddr"]);
+                $log_msg = sprintf($msgarr['12005'][LOG_MSG],
+                                   $_POST["newaddr"]);
+                $logstr = OPERATION . ":OK:" . $log_msg;
                 $_POST["newaddr"] = "";
             }
         }
@@ -254,7 +200,7 @@ if (isset($_POST["myadd"])) {
 } else if (isset($_POST["myaddlist"])) {
 
     if (get_addr_list($_FILES["filename"]["tmp_name"], $fwaddrs) === FALSE) {
-        $logstr = OPERATION . ":NG:" . $err_msg;
+        $logstr = OPERATION . ":NG:" . $log_msg;
 
     } else {
 
@@ -266,8 +212,8 @@ if (isset($_POST["myadd"])) {
         /* LDAP˼ */
         if ($ret != LDAP_OK) {
             $sys_err = TRUE;
-            $pg->display(NULL);
-            result_log(OPERATION . ":NG:" . $err_msg);
+            result_log(OPERATION . ":NG:" . $log_msg);
+            syserr_display();
             exit (1);
         }
         $dn = $result[0]["dn"];
@@ -280,34 +226,38 @@ if (isset($_POST["myadd"])) {
         $num = mk_addr_list($result[0]["mailForwardingAddr"], $fwaddrs,
                                 $addlist, FALSE);
 
-        /* ᡼󥰥ꥹȥɥ쥹Ȥνʣå */
-        foreach ($addlist as $eachmail) {
-            if ($mladdr == $eachmail) {
-                $err_msg = "᡼륢ɥ쥹᡼󥰥ꥹ" .
-                           "ɥ쥹ȽʣƤޤ";
-                $logstr = OPERATION . ":NG:" . $err_msg;
-                $dup_flg = 1;
-                break;
+        if ($num > 0) {
+            /* ᡼󥰥ꥹȥɥ쥹Ȥνʣå */
+            foreach ($addlist as $eachmail) {
+                if ($mladdr == $eachmail) {
+                    $err_msg = $msgarr['12003'][SCREEN_MSG];
+                    $log_msg = $msgarr['12003'][LOG_MSG];
+                    $logstr = OPERATION . ":NG:" . $log_msg;
+                    $dup_flg = 1;
+                    break;
+                }
             }
-        }
 
-        if (!isset($dup_flg)) {
-            /* °ɲ */
-            if ($num != 0) {
-                $attr = array("mailForwardingAddr" => $addlist);
-                $ret = LDAP_add_attribute($dn, $attr);
-            } else {
-                $ret = LDAP_OK;
-            }
+            if (!isset($dup_flg)) {
+                /* °ɲ */
+                if ($num != 0) {
+                    $attr = array("mailForwardingAddr" => $addlist);
+                    $ret = LDAP_add_attribute($dn, $attr);
+                } else {
+                    $ret = LDAP_OK;
+                }
 
-            if ($ret != LDAP_OK) {
-                if ($ret == LDAP_ERR_DUPLICATE) {
-                    $err_msg = "¸ߤƤ᡼륢ɥ쥹ꤵƤޤ";
+                if ($ret != LDAP_OK) {
+                    if ($ret == LDAP_ERR_DUPLICATE) {
+                        $err_msg = $msgarr['12006'][SCREEN_MSG];
+                        $log_msg = $msgarr['12006'][LOG_MSG];
+                    }
+                    $logstr = OPERATION . ":NG:" . $log_msg;
+                } else {
+                    $err_msg = $msgarr['12007'][SCREEN_MSG];
+                    $log_msg = $msgarr['12007'][LOG_MSG];
+                    $logstr = OPERATION . ":OK:" . $log_msg;
                 }
-                $logstr = OPERATION . ":NG:" . $err_msg;
-            } else {
-                $err_msg = "᡼륢ɥ쥹ɲäޤ";
-                $logstr = OPERATION . ":OK:" . $err_msg;
             }
         }
     }
@@ -326,8 +276,8 @@ if (isset($_POST["myadd"])) {
         /* LDAP˼ */
         if ($ret != LDAP_OK) {
             $sys_err = TRUE;
-            $pg->display(NULL);
-            result_log(OPERATION . ":NG:" . $err_msg);
+            result_log(OPERATION . ":NG:" . $log_msg);
+            syserr_display();
             exit (1);
         }
         $dn = $result[0]["dn"];
@@ -339,7 +289,7 @@ if (isset($_POST["myadd"])) {
                             $dellist, TRUE);
 
         /* LDAP° */
-        if ($num != 0) {
+        if ($num > 0) {
             $ret = LDAP_del_attribute($dn, array("mailForwardingAddr" =>
                                                  $dellist));
         } else {
@@ -348,19 +298,33 @@ if (isset($_POST["myadd"])) {
 
         if ($ret != LDAP_OK) {
             if ($ret == LDAP_ERR_NOATTR) {
-                $err_msg = "˺Ƥ᡼륢ɥ쥹ꤵƤޤ(dn=$dn)";
+                $err_msg = sprintf($msgarr['12008'][SCREEN_MSG], $dn);
+                $log_msg = sprintf($msgarr['12008'][LOG_MSG], $dn);
             }
-            $logstr = OPERATION . ":NG:" . $err_msg;
+            $logstr = OPERATION . ":NG:" . $log_msg;
         } else {
-            $err_msg = "᡼륢ɥ쥹ޤ({$_POST["addr"][0]})";
-            $logstr = OPERATION . ":OK:" . $err_msg;
+            $dispaddrs = $_POST["addr"][0];
+            for ($i = 1; $i < count($_POST["addr"]); $i++) {
+                $dispaddrs .= ", " . $_POST["addr"][$i];
+            }
+            $err_msg = sprintf($msgarr['12009'][SCREEN_MSG], $dispaddrs);
+            $log_msg = sprintf($msgarr['12009'][LOG_MSG], $dispaddrs);
+            $logstr = OPERATION . ":OK:" . $log_msg;
         }
 
     } else {
-        $err_msg = "᡼륢ɥ쥹򤵤Ƥޤ";
-        $logstr = OPERATION . ":NG:" . $err_msg;
+        $err_msg = $msgarr['12010'][SCREEN_MSG];
+        $log_msg = $msgarr['12010'][LOG_MSG];
+        $logstr = OPERATION . ":NG:" . $log_msg;
     }
     result_log($logstr);
+
+/* 󥻥 */
+} else if (isset($_POST["cancel"])) {
+
+    /* 桼˥塼̤ */
+    dgp_location("./index.php");
+    exit;
 }
 
 /* ᡼륢ɥ쥹μ */
@@ -371,9 +335,9 @@ $ret = main_get_entry($search_dn, $filter, array(),
 /* LDAP˼ */
 if ($ret != LDAP_OK) {
     $sys_err = TRUE;
-    result_log(OPERATION . ":NG:" . $err_msg);
     $err_msg = htmlspecialchars($err_msg);
-    $pg->display(NULL);
+    result_log(OPERATION . ":NG:" . $log_msg);
+    syserr_display();
     exit (1);
 }
 $dn = $result[0]["dn"];
@@ -389,7 +353,40 @@ $dispml = $result[0]["$dispmlatt"][0];
  * ɽ
  **********************************************************/
 
+/* ᡼륢ɥ쥹ݻ */
+$newaddr = "";
+if (isset($_POST["newaddr"])) {
+    $newaddr = htmlspecialchars($_POST["newaddr"]);
+}
+
+$mailaddrs = "";
+/* ᡼륢ɥ쥹Υȥ꤬ */
+if (isset($result[0]["mailForwardingAddr"])) {
+    /* ᡼륢ɥ쥹Υȥ򥽡 */
+    sort($result[0]["mailForwardingAddr"]);
+    reset($result[0]["mailForwardingAddr"]);
+
+    /* ᡼륢ɥ쥹Υȥ򣱤ĤļɽѤ˲ù */
+    foreach($result[0]["mailForwardingAddr"] as $i) {
+        $addr = $i;
+        $addr = htmlspecialchars($addr);
+        $mailaddrs .= "<option value=\"$addr\">$addr" . "\n";
+    }
+}
+
+/* ͤ򥻥å */
+set_tag_common($tag, "");
+$tag["<<MLADDR>>"] = $dispml = htmlspecialchars($dispml);
+$tag["<<HIDDEN>>"] = "<input type='hidden' name='mladdr' value='$enc_ml'>";
+$tag["<<NEWADDR>>"] = $newaddr;
+$tag["<<MAILADDRS>>"] = $mailaddrs;
+
 /* ڡν */
-$pg->display(CONTENT);
+$ret = display(TMPLFILE, $tag, array(), "", "");
+if ($ret === FALSE) {
+    result_log($log_msg, LOG_ERR);
+    syserr_display();
+    exit(1);
+}
 
 ?>
