@@ -24,8 +24,8 @@
  * CSV
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/10 05:26:46 $
+ * $Revision: 1.5 $
+ * $Date: 2012/09/18 05:17:21 $
  **********************************************************/
 
 include_once("../../initial");
@@ -35,20 +35,26 @@ include_once("lib/dglibpage");
 include_once("lib/dglibsess");
 include_once("lib/dglibldap");
 
-/***********************************************************
- * 饹: ˥塼
- **********************************************************/
-Class my_page extends page {
+define("TMPLFILE", "admin_user_csv.tmpl");
 
-    /***********************************************************
-     * ܥǥɽʥС饤ɡ
-     **********************************************************/
-    function display_body() {
+/*********************************************************
+ * set_tag_data()
+ *
+ * 󥻥åȴؿ
+ *
+ * []
+ *      $post           Ϥ줿
+ *      $tag            
+ *
+ * [֤]
+ *      ʤ
+ ********************************************************/
+function set_tag_data($post, &$tag) {
 
-        global $web_conf;
-        global $sesskey;
+    global $web_conf;
+    global $sesskey;
 
-        print <<<EOD
+    $tag["<<JAVASCRIPT>>"] = <<<EOD
 <script type="text/javascript">
 <!--
   function resultwindow() {
@@ -64,59 +70,46 @@ Class my_page extends page {
           return false;
       }
   }
+  function msgConfirm(msg) {
+          return(window.confirm(msg));
+  }
+  function dgpSubmit(url) {
+      document.common.action = url;
+      document.common.submit();
+  }
 // -->
 </script>
-<form name="form" method="POST" action="result.php" enctype="multipart/form-data">
-  <table class="table">
-    <tr>
-      <td class="key1">ư</td>
-      <td class="value">
-      <input type="radio" name="runtype" value="add" checked>Ͽ
-      <input type="radio" name="runtype" value="del"></td>
-    </tr>
-    <tr>
-      <td class="key1" rowspan="2">ץ</td>
-      <td class="value">
-      <input type="checkbox" name="change" value=ON>¸Υǡ񤭡ʺξ̵뤵ޤ</td>
-    <tr>
-      <td class="value">
-      <input type="checkbox" name="err" value=ON>顼ξ³</td>
-    </tr>
-    <tr>
-      <td class="key1">åץɥե</td>
-      <td class="value">
-        <input type="file" name="uploadfile" size=50></td>
-    </tr>
-    <tr>
-      <td class="key1">եå</td>
-      <td class="value"><input type="submit" name="fcheck" value="" class="file_check_btn" onClick="resultwindow()"></td>
-    </tr>
-  </table><br>
-  <input type="hidden" name="sk" value="$sesskey">
-  <input type="submit" name="upload" value="" class="mod_btn" onClick="return uploadconfirm('CSV򳫻Ϥޤ\\nǤ?')">
-</form>
 EOD;
 
-    }
-};
+}
 
 /***********************************************************
  * 
  **********************************************************/
-/* 󥹥󥹺 */
-$pg = new my_page();
+/*  */
+$tag = array();
 
 /* ե롢ִեɹåΥå */
 $ret = init();
 if ($ret === FALSE) {
-    $sys_err = TRUE;
-    $pg->display(NULL);
+    syserr_display();
     exit (1);
 }
 
 /***********************************************************
  * ɽ
  **********************************************************/
-$pg->display(CONTENT);
+/* ̤Υ */
+set_tag_common($tag);
+
+/* β̤Υ */
+set_tag_data($_POST, $tag);
+
+$ret = display(TMPLFILE, $tag, array(), "", "");
+if ($ret === FALSE) {
+    syserr_display();
+    result_log($log_msg, LOG_ERR);
+    exit(1);
+}
 
 ?>
