@@ -24,8 +24,8 @@
  * CSV̲
  *
  * $RCSfile: result.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/24 08:46:27 $
+ * $Revision: 1.7 $
+ * $Date: 2012/09/13 02:58:51 $
  **********************************************************/
 
 include_once("../../initial");
@@ -38,7 +38,7 @@ include_once("lib/dglibldap");
 /********************************************************
 ƥڡ
 *********************************************************/
-define("OPERATION", "CSVϿ");
+define("OPERATION", "Registering CSV at once");
 
 /* CSV֤ */
 define("CSV_BATCH_OK", 0);             # 
@@ -135,14 +135,17 @@ function mk_ldap_array($csvdata)
  **********************************************************/
 function fcheck_add_user_duplicate($userdata, $fcheckuser)
 {
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
 
     $max = count($fcheckuser);
     for ($i = 0; $i < $max; $i++) {
         /* 桼̾Υå */
         if ($fcheckuser[$i]["uid"] == $userdata["uid"] ||
             $fcheckuser[$i]["alias"] == $userdata["uid"]) {
-            $err_msg = "ꤵ줿桼ϴϿƤޤ";
+            $err_msg = $msgarr['14001'][SCREEN_MSG];
+            $log_msg = $msgarr['14001'][LOG_MSG];
             return FALSE;
         }
 
@@ -150,7 +153,8 @@ function fcheck_add_user_duplicate($userdata, $fcheckuser)
         if ($userdata["alias"] != "") {
             if ($fcheckuser[$i]["uid"] == $userdata["alias"] ||
                 $fcheckuser[$i]["alias"] == $userdata["alias"]) {
-                $err_msg = "ꤵ줿᡼륨ꥢϴϿƤޤ";
+                $err_msg = $msgarr['14002'][SCREEN_MSG];
+                $log_msg = $msgarr['14002'][LOG_MSG];
                 return FALSE;
             }
         }
@@ -175,13 +179,16 @@ function fcheck_add_user_duplicate($userdata, $fcheckuser)
  **********************************************************/
 function is_fcheck_del_user($userdata, $fcheckuser)
 {
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
 
     $max = count($fcheckuser);
     for ($i = 0; $i < $max; $i++) {
         /* 桼̾Υå */
         if ($fcheckuser[$i]["uid"] == $userdata["uid"]) {
-            $err_msg = "ꤵ줿桼ϴ˺Ƥޤ";
+            $err_msg = $msgarr['14003'][SCREEN_MSG];
+            $log_msg = $msgarr['14003'][LOG_MSG];
             return FALSE;
         }
     }
@@ -208,7 +215,9 @@ function is_fcheck_del_user($userdata, $fcheckuser)
  **********************************************************/
 function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
 {
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
     global $web_conf;
     global $domain;
     global $userdn;
@@ -222,7 +231,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
         if (isset($_POST["err"])) {
             return CSV_BATCH_NG_ERR_IGNORE;
         } else {
@@ -238,7 +247,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
             ob_flush();
             flush();
             result_log($logstr . ":NG:" . $userdata["uid"] .
-                       ":$err_msg(${line})");
+                       ":$log_msg(line ${line})");
             if (isset($_POST["err"])) {
                 return CSV_BATCH_NG_ERR_IGNORE;
             } else {
@@ -261,7 +270,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
         if (isset($_POST["err"])) {
             return CSV_BATCH_NG_ERR_IGNORE;
         } else {
@@ -277,12 +286,13 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
     /* ʣƤϥ顼 */
     if (($type == ADD_MODE && $ret == LDAP_FOUNDUSER) ||
         $ret == LDAP_FOUNDALIAS || $ret == LDAP_FOUNDOTHER) {
-        $err_msg = "ꤵ줿桼ϴϿƤޤ";
+        $err_msg = $msgarr['14001'][SCREEN_MSG];
+        $log_msg = $msgarr['14001'][LOG_MSG];
         printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
         if (isset($_POST["err"])) {
             return CSV_BATCH_NG_ERR_IGNORE;
         } else {
@@ -300,7 +310,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
             ob_flush();
             flush();
             result_log($logstr . ":NG:" . $userdata["uid"] .
-                       ":$err_msg(${line})");
+                       ":$log_msg(line ${line})");
             if (isset($_POST["err"])) {
                 return CSV_BATCH_NG_ERR_IGNORE;
             } else {
@@ -308,13 +318,14 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
             }
         }
         if ($ret == LDAP_FOUNDUSER || $ret == LDAP_FOUNDOTHER) {
-            $err_msg = "ꤵ줿᡼륨ꥢϴϿƤޤ";
+            $err_msg = $msgarr['14002'][SCREEN_MSG];
+            $log_msg = $msgarr['14002'][LOG_MSG];
             printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]),
                    $err_msg);
             ob_flush();
             flush();
             result_log($logstr . ":NG:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
             if (isset($_POST["err"])) {
                 return CSV_BATCH_NG_ERR_IGNORE;
             } else {
@@ -326,12 +337,13 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
     /* ǥ̥å */
     $quotalen = strlen($userdata["quota"]);
     if ($quotalen > $web_conf[$url_data["script"]]["quotasize"]) {
-        $err_msg = "᡼ܥå̤ηǤ";
+        $err_msg = $msgarr['14004'][SCREEN_MSG];
+        $log_msg = $msgarr['14004'][LOG_MSG];
         printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
         if (isset($_POST["err"])) {
             return CSV_BATCH_NG_ERR_IGNORE;
         } else {
@@ -345,7 +357,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
         if (isset($_POST["err"])) {
             return CSV_BATCH_NG_ERR_IGNORE;
         } else {
@@ -362,7 +374,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
                 ob_flush();
                 flush();
                 result_log($logstr . ":NG:" .  $userdata["uid"] .
-                           ":$err_msg(${line})");
+                           ":$log_msg(line ${line})");
                 if (isset($_POST["err"])) {
                     return CSV_BATCH_NG_ERR_IGNORE;
                 } else {
@@ -372,12 +384,13 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         }
 
         /* Ͽ */
-        $err_msg = "Ͽ˽λޤ";
+        $err_msg = $msgarr['14005'][SCREEN_MSG];
+        $log_msg = $msgarr['14005'][LOG_MSG];
         printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":OK:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
 
     } else {
         // LDAPѹ
@@ -388,7 +401,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
                 ob_flush();
                 flush();
                 result_log($logstr . ":NG:" .  $userdata["uid"] .
-                           ":$err_msg(${line})");
+                           ":$log_msg(line ${line})");
                 if (isset($_POST["err"])) {
                     return CSV_BATCH_NG_ERR_IGNORE;
                 } else {
@@ -398,12 +411,13 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         }
 
         /* ѹ */
-        $err_msg = "ѹ˽λޤ";
+        $err_msg = $msgarr['14006'][SCREEN_MSG];
+        $log_msg = $msgarr['14006'][LOG_MSG];
         printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":OK:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
     }
     return CSV_BATCH_OK;
 
@@ -429,7 +443,9 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
  **********************************************************/
 function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
 {
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
     global $domain;
     global $web_conf;
     global $userdn;
@@ -437,12 +453,13 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
 
     /* CSVηå */
     if ($userdata["uid"] == "") {
-        $err_msg = "桼̾ηǤ";
+        $err_msg = $msgarr['14007'][SCREEN_MSG];
+        $log_msg = $msgarr['14007'][LOG_MSG];
         printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
         if (isset($_POST["err"])) {
             return CSV_BATCH_NG_ERR_IGNORE;
         } else {
@@ -458,7 +475,7 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
             ob_flush();
             flush();
             result_log($logstr . ":NG:" . $userdata["uid"] .
-                       ":$err_msg(${line})");
+                       ":$log_msg(line ${line})");
             if (isset($_POST["err"])) {
                 return CSV_BATCH_NG_ERR_IGNORE;
             } else {
@@ -474,12 +491,13 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
 
     /* 桼̾¸ߥå */
     if (get_userdata_connect($userdn, $ds) === FALSE) {
-        $err_msg = "ꤵ줿桼ϴ˺Ƥޤ";
+        $err_msg = $msgarr['14003'][SCREEN_MSG];
+        $log_msg = $msgarr['14003'][LOG_MSG];
         printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
-                   ":$err_msg(${line})");
+                   ":$log_msg(line ${line})");
         if (isset($_POST["err"])) {
             return CSV_BATCH_NG_ERR_IGNORE;
         } else {
@@ -495,7 +513,7 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
             ob_flush();
             flush();
             result_log($logstr . ":NG:" . $userdata["uid"] .
-                       ":$err_msg(${line})");
+                       ":$log_msg(line ${line})");
             if (isset($_POST["err"])) {
                 return CSV_BATCH_NG_ERR_IGNORE;
             } else {
@@ -505,11 +523,12 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
     }
 
     /*  */
-    $err_msg = "˽λޤ";
+    $err_msg = $msgarr['14008'][SCREEN_MSG];
+    $log_msg = $msgarr['14008'][LOG_MSG];
     printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
     ob_flush();
     flush();
-    result_log($logstr . ":OK:" . $userdata["uid"] . ":$err_msg(${line})");
+    result_log($logstr . ":OK:" . $userdata["uid"] . ":$log_msg(line ${line})");
 
     return CSV_BATCH_OK;
 
@@ -534,12 +553,17 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
  **********************************************************/
 function csv_column_check($csvdata, $num, $line, $logstr)
 {
+    global $msgarr;
+    global $err_msg;
+    global $log_msg;
+
     if (count($csvdata) < $num) {
-        $err_msg = "οǤ";
+        $err_msg = $msgarr['14009'][SCREEN_MSG];
+        $log_msg = $msgarr['14009'][LOG_MSG];
         printf(CSV_NG_MSG, $line, "", $err_msg);
         ob_flush();
         flush();
-        result_log($logstr . ":NG:******:$err_msg(${line})");
+        result_log($logstr . ":NG:******:$log_msg(line ${line})");
         if (isset($_POST["err"])) {
             return CSV_BATCH_NG_ERR_IGNORE;
         } else {
@@ -565,7 +589,9 @@ function csv_column_check($csvdata, $num, $line, $logstr)
  **********************************************************/
 function read_csvfile($fp, $logstr)
 {
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
     $line = 0;
     $fchecknum = 0;
     $fcheckuser = array();
@@ -633,7 +659,8 @@ function read_csvfile($fp, $logstr)
 
     /* եξ票顼 */
     if ($line == 0) {
-        $err_msg = "Υե뤬ꤵƤޤ";
+        $err_msg = $msgarr['14010'][SCREEN_MSG];
+        $log_msg = $msgarr['14010'][LOG_MSG];
         return FALSE;
     }
 
@@ -657,7 +684,9 @@ function print_csv_result()
 {
     global $web_conf;
     global $domain;
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
     global $admkey_file;
     global $userdn;
     global $basedir;
@@ -666,13 +695,9 @@ function print_csv_result()
     /***********************************************************
      * 
      **********************************************************/
-    /* 󥹥󥹺 */
-    $pg = new page();
-
     /* إå */
-    $pg->output_http_header();
-    $pg->display_header();
-    print("</head>\n");
+    output_http_header();
+    display_header();
 
     /* $basedir$topdirΥå */
     url_search();
@@ -689,7 +714,7 @@ function print_csv_result()
     $ret = read_web_conf($url_data["script"]);
     if ($ret === FALSE) {
         print($err_msg);
-        $pg->display_footer();
+        display_footer();
         exit(1);    
     }
 
@@ -697,21 +722,29 @@ function print_csv_result()
     $ret = read_tab_conf(ADMINTABCONF);
     if ($ret === FALSE) {
         print($err_msg);
-        $pg->display_footer();
+        display_footer();
+        exit(1);    
+    }
+
+    /* åեɹ */
+    $ret = make_msgarr(MESSAGEFILE);
+    if ($ret === FALSE) {
+        print($err_msg);
+        display_footer();
         exit(1);    
     }
 
     /* å */
     if (isset($sesskey) === FALSE) {
         print("ˡǤ");
-        $pg->display_footer();
+        display_footer();
         exit(1);    
     }
 
     /* åå */
     if (is_sysadm($sesskey) !== TRUE) {
         print("å̵Ǥ");
-        $pg->display_footer();
+        display_footer();
         exit(1);    
     }
 
@@ -722,39 +755,51 @@ function print_csv_result()
      * main
      **********************************************************/
     if (isset($_POST["fcheck"]) || isset($_POST["upload"])) {
-        # ʸ
+        /* ʸ */
         $logstr = OPERATION;
 
+        /* ưפꤵƤ뤫å */
+        if (isset($_POST["runtype"]) === FALSE) {
+            $err_msg = $msgarr['14013'][SCREEN_MSG];
+            $log_msg = $msgarr['14013'][LOG_MSG];
+            print($err_msg);
+            display_footer();
+            result_log($logstr . ":NG:" .  $log_msg);
+            exit(1);    
+        }
+
         /* CSVե뤬ꤵƤ뤫ɤå */
         if (($_FILES["uploadfile"]["tmp_name"]) == "") {
-            $err_msg = "åץɥե뤬ꤵƤޤ";
+            $err_msg = $msgarr['14011'][SCREEN_MSG];
+            $log_msg = $msgarr['14011'][LOG_MSG];
             print($err_msg);
-            $pg->display_footer();
-            result_log($logstr . ":NG:" .  $err_msg);
+            display_footer();
+            result_log($logstr . ":NG:" .  $log_msg);
             exit(1);    
         } else {
             /* åץɥե륪ץ */
             $fp = fopen($_FILES["uploadfile"]["tmp_name"], 'r');
             if ($fp === FALSE) {
-                $err_msg = "åץɥեΥץ˼Ԥޤ";
+                $err_msg = $msgarr['14012'][SCREEN_MSG];
+                $log_msg = $msgarr['14012'][LOG_MSG];
                 print($err_msg);
-                $pg->display_footer();
-                result_log($logstr . ":NG:" .  $err_msg);
+                display_footer();
+                result_log($logstr . ":NG:" .  $log_msg);
                 exit(1);    
             } else {
                 /* CSVեɹ */
                 if (read_csvfile($fp, $logstr) === FALSE) {
                     fclose($fp);
                     print($err_msg);
-                    $pg->display_footer();
-                    result_log($logstr . ":NG:" .  $err_msg);
+                    display_footer();
+                    result_log($logstr . ":NG:" .  $log_msg);
                     exit(1);    
                 }
                 fclose($fp);
             }
         }
     }
-    $pg->display_footer();
+    display_footer();
 }
 /***********************************************************
  * ɽ
