@@ -24,8 +24,8 @@
  * ѥ桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.3 $
- * $Date: 2010/06/23 09:04:46 $
+ * $Revision: 1.15 $
+ * $Date: 2012/09/26 06:33:03 $
  **********************************************************/
 
 include_once("../../initial");
@@ -39,117 +39,105 @@ include_once("lib/dglibldap");
 ƥڡ
 *********************************************************/
 
-define("OPERATION",  "桼ȸ");
+define("TMPLFILE", "admin_user_search.tmpl");
+
+define("OPERATION",  "Searching user account");
 
 define("STATUS_INPUT",  0);
 define("STATUS_SEARCH", 1);
-
-/***********************************************************
- * 饹: ˥塼
- **********************************************************/
-Class my_page extends page {
-
-    /***********************************************************
-     * ܥǥɽʥС饤ɡ
-     **********************************************************/
-    function display_body() {
-        print_form();
-    }
-};
-
 /*********************************************************
- * print_form
+ * set_tag_data
  *
- * ϥե
+ * Υå
  *
  * []
- *        ʤ
+ *        $post              POSTϤ줿
+ *        $form_name         եϤ̾
+ *        $ldap_result       LDAP
+ *        $filter_disp       LDAPե륿
+ *        $form_name_encode  󥳡ɤ줿ե
+ *        $tag               Ǽ
  *
  * [֤]
- *        ʤ
- *
+ *        TRUE               
  **********************************************************/
-function print_form()
+function set_tag_data($post, $form_name, $ldap_result, $filter_disp, $form_name_encode, &$page, &$tag)
 {
     global $web_conf;
-    global $status;
-    global $sesskey;
-    global $form_name;
 
+    /* JavaScript */
+    $javascript = <<<EOD
+    function allSubmit(url, page, dn, form_name_encode) {
+        document.all.action = url;
+        document.all.page.value = page;
+        document.all.dn.value = dn;
+        document.all.form_name.value = form_name_encode;
+        document.all.submit();
+    }
+
+EOD;
+
+    /* ̤ǻȤ */
+    set_tag_common($tag, $javascript);
+
+    /* UID */
+    $tag["<<SEARCH_UID>>"] ="";
     if (isset($form_name)) {
-        $form_name = htmlspecialchars($form_name);
-
-        /* ޥå */
-        if ($_POST["name_match"] == 0) {
-            $name_inc_flg = "selected";
-            $name_mat_flg = "";
-        } elseif ($_POST["name_match"] == 1) {
-            $name_mat_flg = "selected";
-            $name_inc_flg = "";
-        }
-    } else {
-        $form_name ="";
-        $name_inc_flg = "selected";
-        $name_mat_flg = "";
+        $tag["<<SEARCH_UID>>"] = htmlspecialchars($form_name);
     }
 
-    print <<<EOD
-
-<form method="post" name="all" action="index.php">
-<b>桼θ</b><br><br>
-<table class="normal">
-    <tr>
-        <td class="normal" style="text-align:right;">
-          桼̾
-        </td>
-        <td class="normal">
-          <input type="text" size="30" name="form_name" value="{$form_name}" maxlength="256">
-          <select name="name_match">
-              <option value="0" {$name_inc_flg}>ޤ</option>
-              <option value="1" {$name_mat_flg}>Ȱפ</option>
-          </select>
-        </td>
-    </tr>
-</table>
-
-<br>
-<input type="hidden" name="sk" value="$sesskey">
-<input type="submit" name="search" value="" class="search_btn">
-<input type="submit" name="csvdownload" value="" class="csv_btn">
-EOD;
-
-    if($status == STATUS_INPUT) {
-        print_title(0, null);
-    } else {
-        print_result();
+    /* ޥå */
+    $tag["<<INCLUDE_ON>>"] = "selected";
+    $tag["<<MATCH_ON>>"] = "";
+    if (isset($post["name_match"]) && $post["name_match"] == 1) {
+        $tag["<<MATCH_ON>>"] = "selected";
+        $tag["<<INCLUDE_ON>>"] = "";
     }
-        print <<<EOD
-</table>
-</form>
+
+    /* hidden */
+    $tag["<<HIDDEN>>"] = "";
+    if (isset($post["search"]) || isset($post["filter"])) {
+
+        $tag["<<HIDDEN>>"] = <<<EOD
+<input type="hidden" name="filter" value="{$filter_disp}">
+<input type="hidden" name="dn">
+<input type="hidden" name="page" value="${page}">
+
 EOD;
+    }
+
+    /* ڡڡ */
+    $tag["<<PRE>>"] = "";
+    $tag["<<NEXT>>"] = "";
+
+    get_page($ldap_result, $page, $form_name_encode, $tag);
+
+    return TRUE;
+
 }
 
 /*********************************************************
- * print_title
+ * get_page
  *
- * ̤Υȥ
+ * ڡڡμ
  *
  * []
- *          $sum     ̤ι׿
- *          $filter  ѥե륿
- *
+ *       $ldap_result       LDAPθ
+ *       $page              ڡ
+ *       $form_name_encode  󥳡ɤ줿
+ *       $tag               
  * [֤]
- *          ʤ
- *
+ *       TRUE               
  **********************************************************/
-function print_title($sum, $filter)
+function get_page($ldap_result, &$page, $form_name_encode, &$tag)
 {
     global $web_conf;
-    global $sesskey;
-    global $page;
-    global $filter_disp;
     global $url_data;
-    global $plugindata;
+
+    $sum = count($ldap_result);
+
+    /*  */
+    $tag["<<NUM>>"] = $sum;
 
     /* ڡֹ0ϤޤäƤ */
     $all_page = (int) ceil(($sum / $web_conf[$url_data["script"]]["lineperpage"]));
@@ -168,104 +156,45 @@ function print_title($sum, $filter)
         $page = $page - 1;
     } 
 
+    /* ǽΥڡǤʤڡɽ */
     if ($page != 0) {
         $tmp = $page - 1;
-        $pre = "<a href=\"#\" onClick=\"allSubmit('index.php', '$tmp', '')\">ڡ</a>";
-        $next = "";
-    } else {
-        $pre = "";
-        $next = "";
+        $tag["<<PRE>>"] = "<a href=\"#\" onClick=\"allSubmit('index.php', '$tmp', '', '$form_name_encode')\">ڡ</a>";
     }
 
+    /* ǸΥڡǤʤмڡɽ */
     if ($page != $all_page - 1) {
         $tmp = $page + 1;
-        $next = "<a href=\"#\" onClick=\"allSubmit('index.php', '$tmp', '')\">ڡ</a>";
+        $tag["<<NEXT>>"] = "<a href=\"#\" onClick=\"allSubmit('index.php', '$tmp', '', '$form_name_encode')\">ڡ</a>";
     }
 
-    /*  */
-    $colum = COLUM_DEF;
-
-    $count = count($plugindata);
-    if ($count > 0) {
-        $colum += $count;
-    }
-
-    print <<<EOD
-
-<script type="text/javascript">
-<!--
-function allSubmit(url, page, dn) {
-    document.all.action = url;
-    document.all.page.value = page;
-    document.all.dn.value = dn;
-    document.all.submit();
-}
-// -->
-</script>
-
-<br>
-<br>
-<input type="hidden" name="filter" value="{$filter_disp}">
-<input type="hidden" name="page" value="{$page}">
-<input type="hidden" name="sk" value="{$sesskey}">
-<input type="hidden" name="dn">
-<table class="table">
-    <tr>
-        <td class="search_sum">[ $sum ]</td>
-        <td colspan="$colum" class="search_tmp" style="border:1px solid #000000;">
-          <table class="guide" align="right">
-            <tr>
-              <td class="search_prev">$pre</td>
-              <td class="search_next">$next</td>
-            </tr>
-          </table>  
-        </td>
-    </tr>
-    <tr>
-        <td class="search_name">桼̾</td>
-        <td class="search_name">᡼륨ꥢ</td>
-        <td class="search_trans">᡼žɥ쥹</td>
-        <td class="search_quota">᡼</td>
-        <td class="search_ref"></td>
-EOD;
-    /* ץ饰ʬɲ */
-    if ($count > 0) {
-        for ($i = 0; $i < $count; $i++) {
-            print<<<EOD
-        <td class="search_ref"></td>
-EOD;
-        }
-    }
-
-    print<<<EOD
-    </tr>
-
-EOD;
-
+    return TRUE;
 }
 
 /*********************************************************
- * print_result
+ * set_loop_tag
  *
  * ̽
  *
  * []
- *       ʤ
+ *       $ldap_result        LDAP
+ *       $filter             ե륿
+ *       $page               ڡ
+ *       $form_name_encode   󥳡ɤ
+ *       $looptag            롼ץ
  *
  * [֤]
  *       ʤ
  **********************************************************/
-function print_result()
+function set_loop_tag($ldap_result, $filter, $page, $form_name_encode, &$looptag)
 {
     global $web_conf;
-    global $ldap_result;
-    global $dispusr;
-    global $filter;
-    global $page;
-    global $limit_adm;
     global $url_data;
     global $plugindata;
 
+    /* 桼̾ɽ° */
+    $dispusr = $web_conf[$url_data['script']]['displayuser'];
+
     /* ̤ɽ°̾ǥ */
     if (isset($ldap_result)) {
         usort($ldap_result, "user_sort");
@@ -275,17 +204,13 @@ function print_result()
         $sum = 0;
     }
 
-    /* ơ֥Υȥɽ */
-    print_title($sum, $filter);
-
     $i = $web_conf[$url_data["script"]]["lineperpage"] * $page;
     $tmp = $i + $web_conf[$url_data["script"]]["lineperpage"];
+    $k = 0;
 
     /* ɽ */
     $max = ($tmp < $sum) ? $tmp : $sum;
-
     while ($i < $max) {
-
         /* dnǼ */
         $userdn = $ldap_result[$i]["dn"];
         $userdn = base64_encode($userdn);
@@ -340,36 +265,42 @@ function print_result()
             }
         }
 
+        $looptag[$k]["<<UID>>"] = $name;
+        $looptag[$k]["<<ALIAS>>"] = $alias;
+        $looptag[$k]["<<TRANS>>"] = $trans;
+        $looptag[$k]["<<QUOTA>>"] = $quota;
+        $looptag[$k]["<<MOD>>"] = <<<EOD
+<input type="button" class="list_mod_btn" onClick="allSubmit('mod.php', '$page', '$userdn', '$form_name_encode')" title="桼
+Խ">
+
+EOD;
+
         /* ץ饰Խ̤ؤΥɽ */
-        $html_plugin = "";
         $count = count($plugindata);
         if ($count > 0) {
             for ($j = 0; $j < $count; $j++) {
+                /*  */
+                $looptag[$k]["<<PLUGIN$j>>"] = "";
+
                 $p_name = $plugindata[$j]["name"];
                 $file = $plugindata[$j]["file"];
                 $image = $plugindata[$j]["image"];
-                $html_plugin .=<<<EOD
-        <td class="value_center"><input type="button" class="plugin_btn" style="background:url(images/${image});" onClick="allSubmit('$file', '$page', '$userdn')" title="${p_name}Խ"></td>
+                $looptag[$k]["<<PLUGIN$j>>"] .=<<<EOD
+        <input type="button" class="plugin_btn" style="background:url(images/${image});" onClick="allSubmit('$file', '$page', '$userdn', '$form_name_encode')" title="${p_name}Խ">
 EOD;
             }
         }
 
-        print <<<EOD
-    <tr>
-        <td class="value">{$name}</td>
-        <td class="value_alias">{$alias}</td>
-        <td class="value_trans">{$trans}</td>
-        <td class="value_right">{$quota}</td>
-        <td class="value_center"><input type="button" class="list_mod_btn" onClick="allSubmit('mod.php', '$page', '$userdn')" title="桼Խ"></td>
-$html_plugin
-    </tr>
-
-EOD;
+        /* ɽǤΥ롼 */
         $i++;
+
+        /* 0Υ롼 */
+        $k++;
     }
 
 }
 
+
 /*********************************************************
  * csv_output
  *
@@ -382,7 +313,8 @@ EOD;
  *           FALSE    ۾
  *
  **********************************************************/
-function csv_output(){
+function csv_output()
+{
 
     global $dispusr;
     global $ldap_result;
@@ -480,19 +412,23 @@ function mk_csv_line($csvdata) {
  **********************************************************/
 function form_check($data)
 {
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
 
     /* 桼̾ηå */
     $ret = check_search_name($data['form_name']);
     if ($ret === FALSE) {
-        $err_msg = "桼̾ηǤ";
+        $err_msg = $msgarr['15001'][SCREEN_MSG];
+        $log_msg = $msgarr['15001'][LOG_MSG];
         return FALSE;
     }	
 
     /* 桼Υå */
     $ret = check_flg($data['name_match']);
     if ($ret === FALSE) {
-        $err_msg = "桼̾θ郎Ǥ";
+        $err_msg = $msgarr['15002'][SCREEN_MSG];
+        $log_msg = $msgarr['15002'][LOG_MSG];
         return FALSE;
     }	
 
@@ -502,8 +438,25 @@ function form_check($data)
 /***********************************************************
  * 
  **********************************************************/
-/* 󥹥󥹺 */
-$pg = new my_page();
+/* ͤν */
+$tag["<<QUOTASIZE>>"] = "";
+$tag["<<UID>>"] = "";
+$tag["<<QUOTA>>"] = "";
+$tag["<<QUOTAUNIT>>"] = "";
+$tag["<<ALIAS>>"] = "";
+$tag["<<TRANS>>"] = "";
+$tag["<<SAVEON>>"] = "";
+$tag["<<SAVEOFF>>"] = "";
+$tag["<<HIDDEN>>"] = "";
+
+$looptag = array();
+
+$ldap_result = array();
+$filter = "";
+$filter_disp = "";
+$form_name = "";
+$form_name_encode = "";
+$page = 0;
 
 /* եϤ줿 */
 if (isset($_POST['form_name'])) {
@@ -521,8 +474,7 @@ if (isset($_POST["search"]) || isset($_POST["filter"]) ||
 /* ե롦ִեɹåå */
 $ret = init();
 if ($ret === FALSE) {
-    $sys_err = TRUE;
-    $pg->display(NULL);
+    syserr_display();
     exit (1);
 }
 
@@ -534,47 +486,49 @@ set_plugindata();
  **********************************************************/
 /* ɽ° */
 $dispusr = $web_conf[$url_data['script']]['displayuser'];
-
 /* ʬ */
 if ($status == STATUS_SEARCH) {
     if ((isset($_POST["search"]) || isset($_POST["csvdownload"])) &&
          form_check($_POST) === FALSE) {
         /* ܥ󤬲졢ϤǤСϤʤ */
         $status = STATUS_INPUT;
-        $logstr = OPERATION . ":NG:" . $err_msg;
+        $logstr = OPERATION . ":NG:" . $log_msg;
         result_log($logstr);
     } else {
         /* Υե륿 */
         if ((!isset($_POST["search"]) && !isset($_POST["csvdownload"])) &&
              $_POST["filter"] != "") {
+
+            /* ڡͥå */
+            if (is_num_check($_POST["page"]) === FALSE) {
+                $err_msg = $msgarr['15003'][SCREEN_MSG];
+                $log_msg = $msgarr['15003'][LOG_MSG];
+                result_log(OPERATION . ":NG:" . $log_msg);
+                syserr_display();
+                exit (1);
+            }
+            $page = $_POST["page"];
+
             /* եϤ줿ͤʣ粽 */
             if (isset($_POST['form_name'])) {
                 $form_name = str_rot13($_POST['form_name']);
                 $form_name = base64_decode($form_name);
             }
 
-            /* ڡͥå */
-            if (is_num_check($_POST["page"]) === FALSE) {
-                $err_msg = "ڡͤǤ";
-                $sys_err = TRUE;
-                $pg->display(NULL);
-                exit (1);
-            }
-            $page = $_POST["page"];
-
             /* ե륿ʣ粽 */
             if (sess_key_decode($_POST["filter"], $filter) === FALSE) {
-                $sys_err = TRUE;
-                $pg->display(NULL);
+                result_log($log_msg, LOG_ERR);
+                syserr_display();
                 exit (1);
             }
 
             /* ե륿ηå */
             $fdata = explode(':', $filter);
             if (count($fdata) != 3) {
-                $err_msg = "ե륿ηǤ";
-                $sys_err = TRUE;
-                $pg->display(NULL);
+                $err_msg = $msgarr['15004'][SCREEN_MSG];
+                $log_msg = $msgarr['15004'][LOG_MSG];
+                result_log(OPERATION . ":NG:" . $log_msg);
+                syserr_display();
                 exit (1);
             }
             $filter = $fdata[1];
@@ -587,24 +541,27 @@ if ($status == STATUS_SEARCH) {
             $filter = "(&($dispusr=*)$filter)";
             $page = 0;
         }
-        $search_dn = sprintf(SEARCH_DN, $web_conf[$url_data["script"]]["ldapusersuffix"], 
+        $search_dn = sprintf(SEARCH_DN, $web_conf[$url_data["script"]]["ldapusersuffix"],
                                         $web_conf[$url_data["script"]]["ldapbasedn"]);
         $ret = main_get_entry($search_dn, $filter, array(),
                               $web_conf[$url_data['script']]['ldapscope'], $ldap_result);
         if ($ret == LDAP_ERR_NODATA ) {
-            $err_msg = "ꤵ줿桼ϸĤޤǤ";
-            $logstr = OPERATION . ":NG:" . $err_msg;
+            $err_msg = $msgarr['15005'][SCREEN_MSG];
+            $log_msg = $msgarr['15005'][LOG_MSG];
+            $logstr = OPERATION . ":NG:" . $log_msg;
             result_log($logstr);
         } elseif ($ret != LDAP_OK) {
             $status = STATUS_INPUT;
-            $logstr = OPERATION . ":NG:" . $err_msg;
+            $logstr = OPERATION . ":NG:" . $log_msg;
             result_log($logstr);
+            syserr_display();
+            exit(1);
         }
 
         /* ե륿ΰŹ沽 */
         if (sess_key_make($filter, "", $filter_disp) === FALSE) {
-            $sys_err = TRUE;
-            $pg->display(NULL);
+            result_log($log_msg, LOG_ERR);
+            syserr_display();
             exit (1);
         }
 
@@ -613,20 +570,39 @@ if ($status == STATUS_SEARCH) {
             $err_msg = htmlspecialchars($_POST["msg"]);
         }
     }
-} 
+}
+
+/* ΰŹ沽 */
+if (isset($_POST['form_name'])) {
+    $form_name_encode = base64_encode($form_name);
+    $form_name_encode = str_rot13($form_name_encode);
+}
+
 
 /***********************************************************
  * ɽ
  **********************************************************/
-
 /* ڡν */
 if (isset($_POST['csvdownload']) && count($ldap_result) > 0) {
-    $err_msg = "CSVեɤޤ";
-    $logstr = OPERATION . ":OK:" . $err_msg;
+    $err_msg = $msgarr['15006'][SCREEN_MSG];
+    $log_msg = $msgarr['15006'][LOG_MSG];
+    $logstr = OPERATION . ":OK:" . $log_msg;
     result_log($logstr);
     csv_output();
     exit(0);
 } else {
-    $pg->display(CONTENT);
+    /*  */
+    set_tag_data($_POST, $form_name, $ldap_result, $filter_disp, $form_name_encode, $page, $tag);
+
+    /* 롼ץκ */
+    set_loop_tag($ldap_result, $filter, $page, $form_name_encode,
+                 $looptag);
+    /* ɽ */
+    $ret = display(TMPLFILE, $tag, $looptag, "<<STARTLOOP>>", "<<ENDLOOP>>");
+    if ($ret === FALSE) {
+        result_log($log_msg, LOG_ERR);
+        syserr_display();
+        exit(1);
+    }
 }
 ?>
